@@ -2,6 +2,16 @@ import numpy.random
 import RSA_tool as my_RSA
 
 
+def test_calculating_keys():
+    e, d, n = my_RSA.RSA.get_bit_keys(1024)
+    m = 'hello world'
+    print(n)
+    c = my_RSA.RSA.block_encrypt(m, e, n)
+    print(c)
+    m = my_RSA.RSA.block_decrypt(c, d, n)
+    print(m)
+
+
 def test():
     m = numpy.random.randint(13, 1000, 20)
     isNorm = True
@@ -16,24 +26,6 @@ def test():
         print("eee i feel good")
 
 
-def test_calculating_keys():
-    e, d, n = my_RSA.RSA.get_bit_keys(1024)
-    m = 'hello world'
-    print(n)
-    c = my_RSA.RSA.block_encrypt(m, e, n)
-    print(c)
-    m = my_RSA.RSA.block_decrypt(c, d, n)
-    print(m)
-
-
-def tmp():
-    # Pypi please let me commit
-    tmp =  2
-    tmp += 1
-    print(tmp)
-    pass
-
-
 def main():
     test_calculating_keys()
 
